@@ -10,7 +10,7 @@
 #   Craig Barratt  <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2004-2013  Craig Barratt
+#   Copyright (C) 2004-2015  Craig Barratt
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #
 #========================================================================
 #
-# Version 3.3.0, released 14 Apr 2013.
+# Version 3.3.1, released 11 Jan 2015.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -152,6 +152,7 @@ use vars qw(%ConfigMeta);
 
     BackupFilesOnly	=> {
             type      => "hash",
+            keyText   => "CfgEdit_Button_New_Share",
             emptyOk   => 1,
             childType => {
                 type      => "list",
@@ -161,6 +162,7 @@ use vars qw(%ConfigMeta);
     },
     BackupFilesExclude	=> {
             type      => "hash",
+            keyText   => "CfgEdit_Button_New_Share",
             emptyOk   => 1,
             childType => {
                 type      => "list",
